/v1/projects/{project_id}/dynamips/devices — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips device »

# /v1/projects/{project_id}/dynamips/devices

Contents

- /v1/projects/{project_id}/dynamips/devices
  - POST /v1/projects/{project_id}/dynamips/devices
    - Parameters
    - Response status codes
    - Input
    - Output

## POST /v1/projects/{project_id}/dynamips/devices

Create a new Dynamips device instance

### Parameters

- project_id: UUID for the project

### Response status codes

- 400: Invalid request
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
device_id |  | string | Dynamips device instance identifier
device_type | ✔ | string | Dynamips device type
name | ✔ | string | Dynamips device name

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
device_id | ✔ | string | Dynamips router instance UUID
mappings |  | object |
name | ✔ | string | Dynamips device instance name
ports |  | array |
project_id | ✔ | string | Project UUID

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips device »